<div align="center">
  <img src="https://alphawallet.com/wp-content/uploads/2021/02/BNB.png" width=200/>
  <h1>Python-BEP20-Token</h1>
  <p>A Python package that models token methods using the <a href="https://github.com/bnb-chain/BEPs/blob/master/BEP20.md">BEP-20 token standard</a> for tokens on the Binance Smart Chain (BSC).</p>
</div>

> NOTE: This package is in development and currently only offers basic functionality...
___
# Installation:

```bash
pip install bep20
```


# Feature List:

* `Methods:`
  - [x] name()
  - [x] symbol()
  - [x] decimals()
  - [x] totalSupply()
  - [x] balanceOf()
  - [x] getOwner()
  - [ ] transfer()
  - [ ] transferFrom()
  - [x] prepare_approve()
    * Returns an uncalled approve() function ready to be signed by the owner.
  - [x] allowance()

